****************************
Experimental ``asyncio`` API
****************************

.. warning::

   The ``asyncio`` API is not thoroughly unit tested, use with caution. Please
   report issues on `GitHub`_.

.. _`GitHub`: https://github.com/python-astrodynamics/spacetrack

.. automodule:: spacetrack.aio
   :members:
   :show-inheritance:
